@@ -85,14 +85,22 @@ returns the handle for subsequent calls to following functions.
 Argument is the name of the application.
 
 =cut
+
 sub new {
     my $class = shift;
     my %args = @_==1? %{$_[0]} : @_;
-    my $self = bless {
+    my $keymap;
+    my $editMode = $args{'editMode'} || 'emacs';
+    if ($editMode eq 'vicmd') {
+	$keymap = Term::ReadLine::Perl5::OO::Keymap::ViKeymap();
+    } else {
+	$keymap = Term::ReadLine::Perl5::OO::Keymap::EmacsKeymap();
+    }
 
+    my $self = bless {
 	char                 => undef, # last character
-	current_keymap       => Term::ReadLine::Perl5::OO::Keymap::EmacsKeymap(),
-	toplevel_keymap      => Term::ReadLine::Perl5::OO::Keymap::EmacsKeymap(),
+	current_keymap       => $keymap,
+	toplevel_keymap      => $keymap,
 	debug                => !!$ENV{CAROLINE_DEBUG},
 	history_base         => 0,
 	history_stifled      => 0,
@@ -105,6 +113,7 @@ sub new {
 	state                => undef, # line buffer and its state
         rl_History           => [],
 	rl_term_set          => \@Term::ReadLine::TermCap::rl_term_set,
+	editMode             => $editMode,
         %args
     }, $class;
     return $self;
